<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 0
	'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-oc',
	'0_langue' => 'Nissart (mistralenc) [oc_ni_mis]',
	'0_liste' => 'spip-oc@rezo.net',
	'0_mainteneur' => 'Sylvain Oliver : spip -at- oliver-fr.org',

	// A
	'access_interface_graphique' => 'Retour a l’interfaça gràfica coumpleta',
	'access_mode_texte' => 'Afichà l’interfaça testuala simplificada',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Moudificà aquel article',
	'admin_modifier_auteur' => 'Moudificà aquel autour',
	'admin_modifier_breve' => 'Moudificà aquela brèva',
	'admin_modifier_mot' => 'Moudificà aqueu mot clau',
	'admin_modifier_rubrique' => 'Moudificà aquela rùbrica',
	'admin_recalculer' => 'Recarculà aquela pàgina',
	'afficher_calendrier' => 'Afichà lou calendari',
	'afficher_trad' => 'afichà li traducioun',
	'alerte_maj_impossible' => '<b>Alèrta !</b> La messa a jou de la basa SQL vers la versioun @version@ es empoussible ; magara que lì a un proublema relatiéu au drech de moudificà la basa de dounada. Vourguès countatà lou vouòstre aubergadour.',
	'alerte_modif_info_concourante' => 'MÈFI : Aquela infourmacioun es estada moudificada d’un autre bias. La valour atuala es :',
	'analyse_xml' => 'Analisa XML',
	'annuler' => 'Anulà',
	'antispam_champ_vide' => 'Vourguès laissà aqueu camp vuèi:',
	'articles_recents' => 'Lu article mai rechent',
	'avis_1_erreur_saisie' => 'Lì a 1 errour en la vouòstra sesìda, vourguès verificà li infourmacioun.',
	'avis_archive_incorrect' => 'lou fichié arquivi noun es un fichié SPIP',
	'avis_archive_invalide' => 'lou fichier arquivi noun es valid',
	'avis_attention' => 'MÈFI !',
	'avis_champ_incorrect_type_objet' => 'Noum de camp incourrect @name@ per un ouget de tìpou @type@',
	'avis_colonne_inexistante' => 'La coulòna @col@ noun esista',
	'avis_erreur' => 'Errour : veire aquì souta',
	'avis_erreur_connexion' => 'Errour de counessioun',
	'avis_erreur_cookie' => 'proublèma de cookie',
	'avis_erreur_fonction_contexte' => 'Errour de prougramacioun. Noun apelà aquela founcioun en aqueu countest.',
	'avis_erreur_mysql' => 'Errour SQL ',
	'avis_erreur_sauvegarde' => 'Errour en la sauvagarda (@type@ @id_objet@) ! ',
	'avis_erreur_visiteur' => 'Proublèma d’achès a l’espaci privat',
	'avis_nb_erreurs_saisie' => 'Lì soun @nb@ errour en la vouòstra sesìda, vourguès verificà li infourmacioun.',

	// B
	'barre_a_accent_grave' => 'Inscrì una A achèntou grave maiùscoula',
	'barre_aide' => 'Utilisà li escourcha tipougràfiqui per enriquì la vouòstra coumpaginacioun',
	'barre_e_accent_aigu' => 'Inscrì una E achèntou agut maiùscoula',
	'barre_eo' => 'Inscrì una E en l’O',
	'barre_eo_maj' => 'Inscrì una E en l’O maiùscoula',
	'barre_euro' => 'Inscrì lou sìmbolou €',
	'barre_gras' => 'Metre en {{gras}}',
	'barre_guillemets' => 'Entourà embé de « virgouleta »',
	'barre_guillemets_simples' => 'Entourà embé de “virgouleta de segount nivèu”',
	'barre_intertitre' => 'Trasfourmà en {{{intertitre}}}',
	'barre_italic' => 'Metre en {itàlicou}',
	'barre_lien' => 'Trasfourmà en [estac ipertèst->http://...]',
	'barre_lien_input' => 'Vourguès endicà l’adressa dóu vouòstre estac (poudès endicà un’adressa web souta la forma http://www.loumieusit.com o simplamen endicà lou número d’un article d’aqueu sit).',
	'barre_note' => 'Trasfourmà en [[Nota de bas de pàgina]]',
	'barre_paragraphe' => 'Creà un paràgrafou',
	'barre_quote' => '<quote>Cità un message</quote>',
	'bouton_changer' => 'Cambià',
	'bouton_chercher' => 'Cercà',
	'bouton_choisir' => 'Chausì',
	'bouton_deplacer' => 'Desplaçà',
	'bouton_download' => 'Telecargà',
	'bouton_enregistrer' => 'Registrà',
	'bouton_radio_desactiver_messagerie_interne' => 'Desativà la messagerìa interna',
	'bouton_radio_envoi_annonces' => 'Mandà lu anounci editourial',
	'bouton_radio_non_envoi_annonces' => 'Noun mandà d’anounci',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Noun mandà la lista dei nouvità',
	'bouton_recharger_page' => 'Recargà aquela pàgina',
	'bouton_telecharger' => 'Telecargà',
	'bouton_upload' => 'Televersà',
	'bouton_valider' => 'Validà',

	// C
	'cal_apresmidi' => 'predinà',
	'cal_jour_entier' => 'jou entié',
	'cal_matin' => 'matin',
	'cal_par_jour' => 'calendari per jou',
	'cal_par_mois' => 'calendari per mès',
	'cal_par_semaine' => 'calendari per semana',
	'choix_couleur_interface' => 'coulou ',
	'choix_interface' => 'chausida de l’interfaça',
	'colonne' => 'Coulòna',
	'confirm_changer_statut' => 'Mèfi, avès demandat de cambià l’estatut d’aquel elemen. Desiràs countinuà ?',
	'correcte' => 'courret', # chaine utilisée dans le debugueur : "validation .. impossible" ou "validation .. correcte"

	// D
	'date_aujourdhui' => 'ancuèi',
	'date_avant_jc' => 'avant lou Crist',
	'date_dans' => 'en @delai@',
	'date_de_mois_1' => '@j@ de genouié',
	'date_de_mois_10' => '@j@ d’outobre',
	'date_de_mois_11' => '@j@ de nouvembre',
	'date_de_mois_12' => '@j@ de decembre',
	'date_de_mois_2' => '@j@ de febrié',
	'date_de_mois_3' => '@j@ de mars',
	'date_de_mois_4' => '@j@ d’abriéu',
	'date_de_mois_5' => '@j@ de mai',
	'date_de_mois_6' => '@j@ de jugne',
	'date_de_mois_7' => '@j@ de julhet',
	'date_de_mois_8' => '@j@ d’aoust',
	'date_de_mois_9' => '@j@ de setembre',
	'date_demain' => 'deman',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_heures_minutes_court' => '@h@h@m@',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ à @heure@',
	'date_fmt_jour_heure_debut_fin' => 'lou @jour@ de @heure_debut@ fin a @heure_fin@',
	'date_fmt_jour_heure_debut_fin_abbr' => 'lou @dtstart@@jour@ de @heure_debut@@dtabbr@ fin a @dtend@@heure_fin@@dtabbr@',
	'date_fmt_jour_mois' => 'lou @jourmois@',
	'date_fmt_jour_mois_annee' => '@jourmois@ dóu @annee@',
	'date_fmt_mois_annee' => '@nommois@ dóu @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => 'lou @nomjour@ @date@',
	'date_fmt_periode' => 'Dau @date_debut@ fin a @date_fin@',
	'date_fmt_periode_abbr' => 'Dau @dtart@@date_debut@@dtabbr@ fin a @dtend@@date_fin@@dtabbr@',
	'date_fmt_periode_from' => 'Dau',
	'date_fmt_periode_to' => 'fin a',
	'date_fmt_saison_annee' => '@saison@ @annee@',
	'date_heures' => 'oura',
	'date_hier' => 'ier',
	'date_il_y_a' => '@delai@ fa',
	'date_jnum1' => '1er',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'dimènegue',
	'date_jour_1_abbr' => 'dmg.',
	'date_jour_1_initiale' => 'dg.',
	'date_jour_2' => 'dilun',
	'date_jour_2_abbr' => 'dil.',
	'date_jour_2_initiale' => 'dl.',
	'date_jour_3' => 'dimars',
	'date_jour_3_abbr' => 'dmr.',
	'date_jour_3_initiale' => 'dm.',
	'date_jour_4' => 'dimècre',
	'date_jour_4_abbr' => 'dmc.',
	'date_jour_4_initiale' => 'dc.',
	'date_jour_5' => 'dijòu',
	'date_jour_5_abbr' => 'dij.',
	'date_jour_5_initiale' => 'dj.',
	'date_jour_6' => 'divendre',
	'date_jour_6_abbr' => 'div.',
	'date_jour_6_initiale' => 'dv.',
	'date_jour_7' => 'dissata',
	'date_jour_7_abbr' => 'dis.',
	'date_jour_7_initiale' => 'ds.',
	'date_jours' => 'jou',
	'date_minutes' => 'minuta',
	'date_mois' => 'mès',
	'date_mois_1' => 'genouié',
	'date_mois_10' => 'outobre',
	'date_mois_10_abbr' => 'out.',
	'date_mois_11' => 'nouvembre',
	'date_mois_11_abbr' => 'nouv.',
	'date_mois_12' => 'decembre',
	'date_mois_12_abbr' => 'dec.',
	'date_mois_1_abbr' => 'gen.',
	'date_mois_2' => 'febrié',
	'date_mois_2_abbr' => 'febr.',
	'date_mois_3' => 'mars',
	'date_mois_3_abbr' => 'mars',
	'date_mois_4' => 'abriéu',
	'date_mois_4_abbr' => 'abr.',
	'date_mois_5' => 'mai',
	'date_mois_5_abbr' => 'mai',
	'date_mois_6' => 'jugne',
	'date_mois_6_abbr' => 'jugne',
	'date_mois_7' => 'julhet',
	'date_mois_7_abbr' => 'julh.',
	'date_mois_8' => 'aoust',
	'date_mois_8_abbr' => 'aoust',
	'date_mois_9' => 'setembre',
	'date_mois_9_abbr' => 'set.',
	'date_saison_1' => 'iver',
	'date_saison_2' => 'prima',
	'date_saison_3' => 'estiéu',
	'date_saison_4' => 'autoun',
	'date_secondes' => 'secounda',
	'date_semaines' => 'semana',
	'date_un_mois' => 'mès',
	'date_une_heure' => 'oura',
	'date_une_minute' => 'minuta',
	'date_une_seconde' => 'secounda',
	'date_une_semaine' => 'semana',
	'dirs_commencer' => ' per fin de coumençà vertadieramen l’instalacioun',
	'dirs_preliminaire' => 'Preliminari : <b>Reglà lu drech d’achès</b>',
	'dirs_probleme_droits' => 'Proublèma de drech d’achès',
	'dirs_repertoires_absents' => '<p><b>Lu repertori seguent noun soun estat trouvat :</b></p><ul>@bad_dirs@.</ul>
  <p>Si pòu que vengue d’un proublema de maiùscoula o minùscula mau messa.
  Verificàs que li minùscula e maiùscoula d’aquelu repertori courrespouòndon ben embé cen qu’es afichat
  aquì soubre ; s’es pas lou cas, renoumàs lu repertori emb’au vouòstre lougiciau FTP per courregì l’errour.</p>
  <p>Un còu qu’aurès fach acò, pourès ',
	'dirs_repertoires_suivants' => '<p><b>Lu repertori seguent noun soun achessible en escritura :</b></p><ul>@bad_dirs@.</ul>
  <p>Per lì remedià, utilisàs lou vouòstre client FTP per fin de reglà lu drech d’achès de cadun
  d’aquelu repertori. La guida d’instalacioun espliga en detalh couma prouchedre.</p>
  <p>Un còu aquesta manipulacioun facha, pourès ',
	'double_occurrence' => 'Doubla ocurença de @balise@',

	// E
	'en_cours' => 'en cours',
	'envoi_via_le_site' => 'Manda vìa lou sit web',
	'erreur' => 'Errour',
	'erreur_balise_non_fermee' => 'darrièra balisa noun clàusa :',
	'erreur_technique_ajaxform' => 'Achident ! Un’errour emprouvisa a empedit de soumetre lou fourmulari. Poudès mai prouvà.',
	'erreur_technique_enregistrement_champs' => 'Una errour tecnicala a empedit de ben registrà lou camp @champs@.',
	'erreur_technique_enregistrement_impossible' => 'Un’errour tecnicala a empedit lou registramen.',
	'erreur_texte' => 'errour',
	'etape' => 'Tapa',

	// F
	'fichier_introuvable' => 'Fichié @fichier@ introuvable',
	'form_auteur_confirmation' => 'Counfirmàs la vouòstra adressa email',
	'form_auteur_email_modifie' => 'La vouòstra adressa email a estada moudificada.',
	'form_auteur_envoi_mail_confirmation' => 'Un courrié electrònicou de counfirmacioun es estat mandat a @email@. Deurès visità l’adressa Web menciounada en aqueu courrié per validà la vouòstra adressa mail.',
	'form_auteur_mail_confirmation' => 'Bouònjou,

Avès demandat à changà la vouòstra adressa e-mail.
Per counfirmà la vouòstra adressa nova, devès vi counetà à
l’adressa aquì souta (senoun la vouòstra demanda
sera ignourada) :

    @url@
',
	'form_deja_inscrit' => 'Sias ja inscrich.',
	'form_email_non_valide' => 'La vouòstra adressa e-mail noun es valida.',
	'form_forum_access_refuse' => 'Poudès pu achèdre en estou sit.',
	'form_forum_bonjour' => 'Bouònjou @nom@,',
	'form_forum_confirmer_email' => 'Pèr counfirmà la vouòstra adressa e-mail, anàs en aquela adressa : @url_confirm@',
	'form_forum_email_deja_enregistre' => 'Aquela adressa e-mail es ja registrada, poudès dounca utilisà lou vouòstre mot de passa abitual.',
	'form_forum_identifiant_mail' => 'Lou vouòstre nouvèl identificant ven de v’èstre mandat per e-mail.',
	'form_forum_identifiants' => 'Identificant persounal',
	'form_forum_indiquer_nom_email' => 'Endicàs aquí lou vouòstre noum e la vouòstra adressa e-mail. Lou vouòstre identificant persounal arriberà rapidamen, per courrié electrònicou.',
	'form_forum_login' => 'login :',
	'form_forum_message_auto' => '(acò es un message automàticou)',
	'form_forum_pass' => 'mot de passa :',
	'form_forum_probleme_mail' => 'Proublèma d’e-mail : l’identificant noun pòu estre mandat.',
	'form_forum_voici1' => 'Vèqui lu vouòstre identificant pèr poudé participà à la vida dóu sit "@nom_site_spip@" (@adresse_site@) :',
	'form_forum_voici2' => 'Vèqui lu vouòstre identificant pèr proupausà d’article 
 sus lou sit "@nom_site_spip@" (@adresse_login@) :',
	'form_indiquer_email' => 'Vourguès endicà la vouòstra adressa e-mail.',
	'form_indiquer_nom' => 'Vourguès endicà lou vouòstre noum.',
	'form_indiquer_nom_site' => 'Vourguès endicà lou noum dóu vouòstre sit.',
	'form_pet_deja_enregistre' => 'Aqueu sit es ja registrat',
	'form_pet_signature_pasprise' => 'La vouòstra firma es pas pilhada en conte.',
	'form_prop_confirmer_envoi' => 'Counfirmà l’espedissioun',
	'form_prop_description' => 'Descricioun/coumentari',
	'form_prop_enregistre' => 'La vouòstra proupòsta es registrada, apareisserà en ligna après validacioun dei respounsable dóu sit.',
	'form_prop_envoyer' => 'Mandà un message',
	'form_prop_indiquer_email' => 'Vourguès endicà una adressa e-mail valida',
	'form_prop_indiquer_nom_site' => 'Vourguès endicà lou noum dóu sit.',
	'form_prop_indiquer_sujet' => 'Vourguès endicà un soujet',
	'form_prop_message_envoye' => 'Message mandat',
	'form_prop_non_enregistre' => 'La vouòstra proupòsta es pas estada registrada.',
	'form_prop_sujet' => 'Soujet',
	'form_prop_url_site' => 'Adressa URL dóu sit',
	'forum_non_inscrit' => 'Noun sias inscrich, o l’adressa o lou mot de passa es erróneou.',
	'forum_par_auteur' => 'per @auteur@',
	'forum_titre_erreur' => 'Errour...',

	// I
	'ical_texte_rss_articles' => 'Lou fichié « backend » dei article d’estou sit si trova a l’adressa :',
	'ical_texte_rss_articles2' => 'Poudès finda outenì de fichié « backend » per lu article de cada rùbrica dóu sit :',
	'ical_texte_rss_breves' => 'Esìsta de mai un fichié que counten li brèva dóu sit. En prechisant un nùmero de rùbrica, outendrès basta li brèva d’aquela rùbrica.',
	'icone_a_suivre' => 'Da sègre',
	'icone_admin_site' => 'Aministracioun dóu sit',
	'icone_agenda' => 'Agenda',
	'icone_aide_ligne' => 'Ajuda',
	'icone_articles' => 'Article',
	'icone_auteurs' => 'Autour',
	'icone_brouteur' => 'Navigacioun rapida',
	'icone_configuration_site' => 'Counfiguracioun',
	'icone_configurer_site' => 'Counfigurà lou vouòstre sit',
	'icone_creer_nouvel_auteur' => 'Creà un nouvel autour',
	'icone_creer_rubrique' => 'Creà una rùbrica',
	'icone_creer_sous_rubrique' => 'Creà una souta-rùbrica',
	'icone_deconnecter' => 'Si descounetà',
	'icone_discussions' => 'Discussioun',
	'icone_doc_rubrique' => 'Doucumen dei rùbrica',
	'icone_ecrire_article' => 'Escriéure un nouvèl article',
	'icone_edition_site' => 'Edicioun',
	'icone_gestion_langues' => 'Gestioun dei lenga',
	'icone_informations_personnelles' => 'Infourmacioun persounali',
	'icone_interface_complet' => 'interfaça coumpleta',
	'icone_interface_simple' => 'Interfaça simplificada',
	'icone_maintenance_site' => 'Mantenença dóu sit',
	'icone_messagerie_personnelle' => 'Messagerìa persounala',
	'icone_repartition_debut' => 'Afichà la reparticioun despì lou prencìpi',
	'icone_rubriques' => 'Rùbrica',
	'icone_sauver_site' => 'Sauvagarda dóu sit',
	'icone_site_entier' => 'Tout lou sit',
	'icone_sites_references' => 'Sit referençat',
	'icone_statistiques' => 'Estatìstica dóu sit',
	'icone_suivi_activite' => 'Sègre la vida dóu sit',
	'icone_suivi_actualite' => 'Evoulucioun dóu sit',
	'icone_suivi_pettions' => 'Sègre/gerà li peticioun',
	'icone_suivi_revisions' => 'Moudificacioun dei article',
	'icone_supprimer_document' => 'Suprimà aqueu doucumen',
	'icone_supprimer_image' => 'Suprimà aquela image',
	'icone_tous_articles' => 'Toui lu vouòstre article',
	'icone_tous_auteur' => 'Toui lu autour',
	'icone_tous_visiteur' => 'Toui lu visitaire',
	'icone_visiter_site' => 'Veire lou sit pùblicou',
	'icone_voir_en_ligne' => 'Veire en ligna',
	'img_indisponible' => 'image indispounible',
	'impossible' => 'empoussible',
	'info_a_suivre' => 'DA SÈGRE »',
	'info_acces_interdit' => 'Achès prouhibit',
	'info_acces_refuse' => 'Achès refudat',
	'info_action' => 'Acioun : @action@',
	'info_administrer_rubriques' => 'Poudès aministrà aquela rùbrica e li sieu souta-rùbrica',
	'info_adresse_non_indiquee' => 'Noun avès endicat d’adressa à prouvà !',
	'info_aide' => 'AJUDA :',
	'info_ajouter_mot' => 'Ajustà aqueu mot',
	'info_annonce' => 'ANOUNCI',
	'info_annonces_generales' => 'Anounci general :',
	'info_article_propose' => 'Article proupausat',
	'info_article_publie' => 'Article publicat',
	'info_article_redaction' => 'Article en cours de redacioun',
	'info_article_refuse' => 'Article refudat',
	'info_article_supprime' => 'Article suprimat',
	'info_articles' => 'Article',
	'info_articles_a_valider' => 'Lu article da validà',
	'info_articles_nb' => '@nb@ article',
	'info_articles_proposes' => 'Article proupausat',
	'info_articles_un' => '1 article',
	'info_auteurs_nombre' => 'autour',
	'info_authentification_ftp' => 'autentificacioun (per FTP).',
	'info_breves_2' => 'brèva',
	'info_breves_nb' => '@nb@ brèva',
	'info_breves_un' => '1 brèva',
	'info_connexion_refusee' => 'Counessioun refusada',
	'info_contact_developpeur' => 'Vourguès countatà un desfouloupaire.',
	'info_contenance' => 'Aqueu sit couten :',
	'info_contribution' => 'countribucioun',
	'info_copyright' => '@spip@ es un lougiciau lìberou distribuit @lien_gpl@.',
	'info_copyright_doc' => 'Per mai d’infourmacioun, veire lou sit <a href="@spipnet@">@spipnet_affiche@</a>.',
	'info_copyright_gpl' => 'souta lichença GPL',
	'info_cours_edition' => 'Lu vouòstre article en cours de redacioun',
	'info_creer_repertoire' => 'Vourguès creà un fichié o un repertori noumat :',
	'info_creer_repertoire_2' => 'en dintre dóu souta-repertori <b>@repertoire@</b>, pi :',
	'info_creer_vignette' => 'creacioun autoumatica de la vigneta',
	'info_creerdansrubrique_non_autorise' => 'Noun avès lu drech suficient per creà un countegut en aquela rùbrica',
	'info_deplier' => 'Desplegà',
	'info_descriptif_nombre' => 'descritiéu :',
	'info_description' => 'Descricioun :',
	'info_description_2' => 'Descricioun :',
	'info_dimension' => 'Dimensioun :',
	'info_documents_nb' => '@nb@ doucumen',
	'info_documents_un' => '1 doucumen',
	'info_ecire_message_prive' => 'Escrieure un message privat',
	'info_email_invalide' => 'Adressa e-mail invalida',
	'info_en_cours_validation' => 'Lu vouòstre article en cours de redacioun',
	'info_en_ligne' => 'Ahura en ligna :',
	'info_envoyer_message_prive' => 'Mandà un message privat en aquel autour',
	'info_erreur_requete' => 'Errour en la requesta :',
	'info_erreur_squelette2' => 'Minga d’esquèletrou <b>@fichier@</b> es dispounibla...',
	'info_erreur_systeme' => 'Errour sistèma (errno @errsys@)',
	'info_erreur_systeme2' => 'Bessai que lou disc dur es plen, o la basa de dounada es degalhada.<br />
<span style="color:red;">Prouvàs de <a href=\'@script@\'>reparà la basa</a>, o countatàs lou vouòstre aubergadour.</span>',
	'info_fini' => 'Es acabat !',
	'info_format_image' => 'Fourmat d’image que pouòdon èstre utilisat per creà de vigneta : @gd_formats@.',
	'info_format_non_defini' => 'fourmat noun definit',
	'info_grand_ecran' => 'Gran ecran',
	'info_image_aide' => 'AJUDA',
	'info_image_process_titre' => 'Mètodou de fabricacioun dei vigneta',
	'info_impossible_lire_page' => '<b>Errour !</b> Empoussible de legì la pàgina <tt><html>@test_proxy@</html></tt> pèr lou proxy <tt>',
	'info_installation_systeme_publication' => 'Instalacioun dóu sistema de publicacioun...',
	'info_installer_documents' => 'Poudès instalà automaticamen toui lu doucumen contengut en lou doussié @upload@.',
	'info_installer_ftp' => 'En la mesura doun sias aministratour, poudès instalà (per FTP) de fichié en lou doussié @upload@ pi lu seleciounà aquì.',
	'info_installer_images' => 'Poudès instalà d’image ai fourmat JPEG, GIF e PNG.',
	'info_installer_images_dossier' => 'Instalà d’image en lou doussié @upload@ per lu poudé seleciounà aquí.',
	'info_interface_complete' => 'interfaça coumpleta',
	'info_interface_simple' => 'Interfaça simplificada',
	'info_joindre_document_article' => 'Poudès jougné en aquel article de doucumen de tìpou',
	'info_joindre_document_rubrique' => 'Poudès jougné en aquela rùbrica de doucumen de tìpou',
	'info_joindre_documents_article' => 'Poudès jougné dau vouòstre article de doucumen de tìpou :',
	'info_l_article' => 'l’article',
	'info_la_breve' => 'la brèva',
	'info_la_rubrique' => 'la rùbrica',
	'info_langue_principale' => 'Lenga principala dóu sit',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ pixel',
	'info_les_auteurs_1' => 'da @les_auteurs@ ',
	'info_logo_format_interdit' => 'Basta lu logo de fourmat @formats@ soun  autourisat.',
	'info_logo_max_poids' => 'Lu logo devon oubligatoriamen faire mens de @maxi@ (aquèu fichié fa @actuel@).',
	'info_mail_fournisseur' => 'vous@fournissur.com',
	'info_message_2' => 'MESSAGE',
	'info_message_supprime' => 'MESSAGE SUPRIMAT',
	'info_messages_nb' => '@nb@ message',
	'info_messages_un' => '1 message',
	'info_mise_en_ligne' => 'Data de messa en ligna :',
	'info_modification_parametres_securite' => 'modificacioun dei parametre de segurtà',
	'info_mois_courant' => 'En cours de mes:',
	'info_mot_cle_ajoute' => 'Lou mot clau seguent es estat ajustat a ',
	'info_multi_herit' => 'Lenga predefinida',
	'info_multi_langues_soulignees' => 'Li <u>lenga soulignadi</u> beneficioun d’una traducioun toutala o parciala dei test de l’interfaça. Se seleciounàs aqueli lenga, touplen d’elemen dóu sit public (data, fourmulari) seràn traduch automaticamen. Per li lenga noun soulignadi, aquelu elemen apareisseràn en la lenga principala dóu sit.',
	'info_multilinguisme' => 'Multilenguisme',
	'info_nom_non_utilisateurs_connectes' => 'Lou vouòstre noum noun aparèisse en la lista dei utilisaire counetat.',
	'info_nom_utilisateurs_connectes' => 'Lou vouòstre noum aparèisse en la lista dei utilisaire counetat.',
	'info_nombre_en_ligne' => 'Ahura en ligna :',
	'info_non_resultat' => 'Minga de resultat per "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Noun utilisàs la messagerìa interna d’estou sit.',
	'info_nouveau_message' => 'AVÈS UN NOUVÈU MESSAGE',
	'info_nouveaux_messages' => 'AVÈS @total_messages@ NOUVÈU MESSAGE',
	'info_numero_abbreviation' => 'N° ',
	'info_obligatoire' => 'Aquela infourmacioun es oubligatorìa',
	'info_pense_bete' => 'NOTA DE RENEMBRANÇA ',
	'info_petit_ecran' => 'Pichoun ecran',
	'info_petition_close' => 'Peticioun plugada',
	'info_pixels' => 'pixel',
	'info_plusieurs_mots_trouves' => 'Plusiur mot clau troubat per "@cherche_mot@":',
	'info_portfolio_automatique' => 'Pouòrtafoliò automatic :',
	'info_premier_resultat' => '[@debut_limit@ premié resultat de @total@]',
	'info_premier_resultat_sur' => ' [@debut_limit@ premié resultat de @total@]',
	'info_propose_1' => '[@nom_site_spip@] proupausa : @titre@',
	'info_propose_2' => 'Article proupausat
----------------',
	'info_propose_3' => 'L’article "@titre@" es proupausat a la publicacioun.',
	'info_propose_4' => 'Sias counvidat a lou venì counsultà e a dounà la vouòstra oupinioun',
	'info_propose_5' => 'en lou fòrou que li es estacat. Es dispounibla a l’adressa :',
	'info_publie_01' => 'L’article "@titre@" es estat validat da @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLICA : @titre@',
	'info_publie_2' => 'Article publicat
----------------',
	'info_rechercher' => 'Recercà',
	'info_rechercher_02' => 'Recercà :',
	'info_remplacer_vignette' => 'Remplaçà la vigneta predefinida per un logo persounalisat :',
	'info_rubriques_nb' => '@nb@ rùbrica',
	'info_rubriques_un' => '1 rùbrica',
	'info_sans_titre_2' => 'sensa titre',
	'info_selectionner_fichier' => 'Poudès seleciounà un fichié dóu doussié @upload@',
	'info_selectionner_fichier_2' => 'Seleciounà un fichié :',
	'info_sites_nb' => '@nb@ sit',
	'info_sites_un' => '1 sit',
	'info_supprimer_vignette' => 'suprimà la vigneta',
	'info_symbole_bleu' => 'Lou sìmbolou <b>blu</b> marca una <b>nota de renembrança</b> : es a dire un message dau vouòstre usage persounal.',
	'info_symbole_jaune' => 'Lou sìmbolou <b>jaune</b> marca un <b>anounci per toui lu redatour </b>: lu aministratour la pouòdon moudificà, cada redatour la pòu veire.',
	'info_symbole_vert' => 'Lou sìmbolou <b>vert</b> marca lu <b>message cambiat embé d’autre utilisaire</b> dóu sit.',
	'info_telecharger_nouveau_logo' => 'Telecargà un  nouvèu logo :',
	'info_telecharger_ordinateur' => 'Telecargà dau vouòstre ourdinatour :',
	'info_tous_resultats_enregistres' => '[toui lu resultat soun registrat]',
	'info_tout_afficher' => 'Tout afichà',
	'info_travaux_texte' => 'Estou sit es pas encara counfigurat. Tournès pu tardi...',
	'info_travaux_titre' => 'Sit en obra',
	'info_trop_resultat' => 'Tròu de resultat per "@cherche_mot@" ; vourguès afinà la recercà.',
	'info_utilisation_messagerie_interne' => 'Utilisàs la messagerìa interna d’estou sit.',
	'info_valider_lien' => 'validà aquel estac',
	'info_verifier_image' => ', vourguès verificà que li vouòstri image soun estadi trasferidi courretamen.',
	'info_vignette_defaut' => 'Vigneta predefinida',
	'info_vignette_personnalisee' => 'Vigneta persounalisada',
	'info_visite' => 'visita :',
	'info_vos_rendez_vous' => 'Lu vouòstre apountamen a venì',
	'infos_vos_pense_bete' => 'Li vouòstri nota de renembrança ',

	// L
	'label_ajout_id_rapide' => 'Ajountamen rapide',
	'label_poids_fichier' => 'Tàia',
	'lien_afficher_icones_seuls' => 'Afichà li icona souleti',
	'lien_afficher_texte_icones' => 'Afichà li icona e lou test',
	'lien_afficher_texte_seul' => 'Afichà lou test soulet',
	'lien_liberer' => 'liberà',
	'lien_liberer_tous' => 'Liberà tout',
	'lien_nouvea_pense_bete' => 'NOUVÈLA NOTA DE RENEMBRANÇA ',
	'lien_nouveau_message' => 'NOVÈU MESSAGE',
	'lien_nouvelle_annonce' => 'NOUVÈL ANOUNCI',
	'lien_petitions' => 'PETICIOUN',
	'lien_popularite' => 'poupularità : @popularite@%',
	'lien_racine_site' => 'RAÏS DÓU SIT',
	'lien_reessayer' => 'reprouvà',
	'lien_repondre_message' => 'Respouòndre en aqueu message',
	'lien_supprimer' => 'suprimà',
	'lien_tout_afficher' => 'Tout afichà',
	'lien_visite_site' => 'visità aqueu sit',
	'lien_visites' => '@visites@ visita',
	'lien_voir_auteur' => 'Veire aquel autour',
	'ligne' => 'Ligna',
	'login' => 'Counessioun',
	'login_acces_prive' => 'achès a l’espaci privat',
	'login_autre_identifiant' => 'si counetà embé un autre identificant',
	'login_cookie_accepte' => 'Vourguès counfigurà lou vouòstre navigatour per que lu acheta (au màncou per estou sit).',
	'login_cookie_oblige' => 'Per v’identificà d’una manièra segura soubre stou sit, vi còu achetà lu cookie.',
	'login_deconnexion_ok' => 'Descounessioun efetuada',
	'login_erreur_pass' => 'Errour de mot de passa.',
	'login_espace_prive' => 'espaci privat',
	'login_identifiant_inconnu' => 'L’identificant « @login@ » es escounouissut.',
	'login_login' => 'Login :',
	'login_login2' => 'Login o adressa email:',
	'login_login_pass_incorrect' => '(Login o mot de passa incourret.)',
	'login_motpasseoublie' => 'mot de passa denembrat ?',
	'login_non_securise' => 'Mèfi, qu’aqueu fourmulari es pas securisat.
			Se noun voulès que lou vouòstre mot de passa sigue
   interchetat sus la taragnina, vourguès ativà Javascript 
   en lou vouòstre navigatour e',
	'login_nouvelle_tentative' => 'Tentativa nouvèla',
	'login_par_ici' => 'Sias registrat... per aquì...',
	'login_pass2' => 'Mot de passa :',
	'login_preferez_refuser' => '<b>Se preferas refudà lu cookie</b>, un autre mètodou de counessioun (mens securisat) es a la vouòstra dispousicioun :',
	'login_recharger' => 'Recargà aquela pàgina',
	'login_rester_identifie' => 'Restà identificat quauqu jou',
	'login_retour_public' => 'Retour au sit pùblicou',
	'login_retour_site' => 'Retour au sit pùblicou',
	'login_retoursitepublic' => 'retour au sit pùblicou',
	'login_sans_cookie' => 'Identificacioun sensa cookie',
	'login_securise' => 'Login securisat',
	'login_sinscrire' => 's’inscriéure',
	'login_test_navigateur' => 'prouva navigatour/recounessioun',
	'login_verifiez_navigateur' => '(verificas pura que lou vouòstre navigatour noun àugue counservat lou mot de passa en memòria...)',

	// M
	'masquer_colonne' => 'Escoundre aquela coulòna',
	'masquer_trad' => 'Escoundre li traducioun',
	'module_fichiers_langues' => 'Fichié de lenga',

	// N
	'navigateur_pas_redirige' => 'Se lou vouòstre navigatour noun es redirigiat, clicàs aquí per continuà.',
	'numero' => 'Nùmero',

	// O
	'occurence' => 'Ocurença',
	'onglet_affacer_base' => 'Escassà la basa',
	'onglet_auteur' => 'L’autour',
	'onglet_contenu_site' => 'Countengut dóu sit',
	'onglet_evolution_visite_mod' => 'Evoulucioun',
	'onglet_fonctions_avances' => 'Founcioun avançadi',
	'onglet_informations_personnelles' => 'Infourmacioun persounali',
	'onglet_interactivite' => 'Interatività',
	'onglet_messagerie' => 'Messagerìa',
	'onglet_repartition_rubrique' => 'Reparticioun da rùbrica',
	'onglet_save_restaur_base' => 'Sauvagardà/restaurà la basa',
	'onglet_vider_cache' => 'Vuà l’amagadou',

	// P
	'pass_choix_pass' => 'Vourguès chausì lou vouòstre nouvèu mot de passa :',
	'pass_erreur' => 'Errour',
	'pass_erreur_acces_refuse' => '<b>Errour :</b> poudès plus achèdre en aqueu sit.',
	'pass_erreur_code_inconnu' => '<b>Errour :</b> aquestou code courrespouònde a mìnga de visitaire qu’an achès en estou sit.',
	'pass_erreur_non_enregistre' => '<b>Errour :</b> l’adressa <tt>@email_oubli@</tt> noun es registrada soubre stou sit.',
	'pass_erreur_non_valide' => '<b>Errour :</b> aquel e-mail <tt>@email_oubli@</tt> noun es valid !',
	'pass_erreur_probleme_technique' => '<b>Errour :</b> per l’encausa d’un proublema tècnicou, l’e-mail noun si pòu estre mandat. ',
	'pass_espace_prive_bla' => 'L’espaci privat d’estou sit es dubèrt ai
  visitaire que si soun inscrich. Un còu registrat,
  pourès counsultà lu article en cours de redacioun,
  proupausà d’article nouvèu e participà a toui lu fòrou.',
	'pass_forum_bla' => 'Avès demandat d’intervenì en un fòrou
  reservat ai visitaire registrat.',
	'pass_indiquez_cidessous' => 'Endicàs aquì souta l’adressa e-mail qu’avès
 			prechendetemen registrat.
			Receverès un e-mail que v’endiquerà couma
			reavé lou vouòstre achès.',
	'pass_mail_passcookie' => '(acò es un message autoumatic)
Per reavé lou vouòstre achès au sit
@nom_site_spip@ (@adresse_site@)

Vourguès anà a l’adressa seguenta:

    @sendcookie@

Pouràs intrà un mot de passa nouvèu
e vi recounetà au sit.

',
	'pass_mot_oublie' => 'Mot de passa denembrat',
	'pass_nouveau_enregistre' => 'Lou vouòstre nouvèu mot de passa es estat registrat.',
	'pass_nouveau_pass' => 'Mot de passa nouvèu',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Denembrança dóu mot de passa',
	'pass_procedure_changer' => 'Per changà lou vouòstre mot de passa, endicàs l’adressa email assouciada au vouòstre conte.',
	'pass_quitter_fenetre' => 'Quità aquesta fenèstra ',
	'pass_rappel_login' => 'Renembrança: lo voastre identificant (login) es « @login@ ».',
	'pass_recevoir_mail' => 'Receverès un e-mail que v’espliquerà couma retroubà lou vouòstre achès au sit.',
	'pass_retour_public' => 'Retour soubre lou sit pùblicou',
	'pass_rien_a_faire_ici' => 'Ren à faire aquì.',
	'pass_vousinscrire' => 'V’inscriéure soubre estou sit',
	'precedent' => 'prechedent',
	'previsualisation' => 'Previsualisacioun',
	'previsualiser' => 'Previsualisà',

	// R
	'retour' => 'Retour',

	// S
	'spip_conforme_dtd' => 'SPIP counsidèra aqueu doucumen couma counforme au sieu DOCTYPE :',
	'squelette' => 'Esquèletrou',
	'squelette_inclus_ligne' => 'esquèletrou enclus, ligna',
	'squelette_ligne' => 'esquèletrou, ligna',
	'stats_visites_et_popularite' => '@visites@ visita ; poupularità : @popularite@',
	'suivant' => 'seguent',

	// T
	'taille_go' => '@taille@ Go',
	'taille_ko' => '@taille@ Ko',
	'taille_mo' => '@taille@ Mo',
	'taille_octets' => '@taille@ octet',
	'texte_actualite_site_1' => 'Coura serès familharisat embé l’interfaça, pourès clicà sus « ',
	'texte_actualite_site_2' => 'interfaça coumpleta',
	'texte_actualite_site_3' => '» per avé mai de poussibilità.',
	'texte_creation_automatique_vignette' => 'La creacioun autoumatica de vigneta de previsualisacioun es ativada soubre estou sit. S’instalàs d’image ai fourmat @gd_formats@ a partì d’estou fourmulari, seràn acoumpagnadi d’una vinheta d’una talha massimala de @taille_preview@ pixel.',
	'texte_documents_associes' => 'Lu doucumen seguent soun assouciat dau article,
				mà soun pas estat diretamen
				inserat. Segoun la coumpaginacioun dóu sit public,
				pouran aparèisse souta fourma de doucumen jounch.',
	'texte_erreur_mise_niveau_base' => 'Errour de basa de dounada dóu tems de la messa a nivèu.
		L’image <b>@fichier@</b> es pas passada (article @id_article@).
		Noutàs ben aquela referença, reprouvàs la messa a
		nivèu, e verificàs pi que lu image aparèisson
		encara en lu article.',
	'texte_erreur_visiteur' => 'Avès prouvat d’achèdre a l’espaci privat emb’un identificant que noun lou permete.',
	'texte_inc_auth_1' => 'Sias identificat couma
		<b>@auth_login@</b>, ma aquèu login noun esista o esista plus en la basa.
		Prouvàs de vi',
	'texte_inc_auth_2' => 'recounetà',
	'texte_inc_auth_3' => ', après avé eventualamen quitat pi
		relançat lou vouòstre navigatour.',
	'texte_inc_config' => 'Li moudificacioun fachi en aqueli pàgina influissoun bravamen lou
 founciounamen dóu vouòstre sit. Vi racoumanden de noun li intervenì tant que noun sias
 familiarisat au founciounamen dóu sistèma SPIP. <br /><br /><b>
 En general, es fouòrça counseiat
 de laissà la carga d’aqueli pàgina au webmestre principal dóu vouòstre sit.</b>',
	'texte_inc_meta_1' => 'Lou sistèma a rescountrat un errour dóu tems de l’escritura dóu fichié <code>@fichier@</code>. Vourguès, couma aministratour dóu sit,',
	'texte_inc_meta_2' => 'verificà lu drech d’escritura',
	'texte_inc_meta_3' => 'sus lou repertori <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'en cours de redacioun',
	'texte_statut_poubelle' => 'dai rementa',
	'texte_statut_propose_evaluation' => 'proupausat per evaluacioun',
	'texte_statut_publie' => 'publicat en ligna',
	'texte_statut_refuse' => 'refudat',
	'titre_ajouter_mot_cle' => 'AJUSTÀ UN MOT CLAU :',
	'titre_cadre_raccourcis' => 'ESCOURCHA :',
	'titre_changer_couleur_interface' => 'Changià la coulou de l’interfaça',
	'titre_image_admin_article' => 'Poudès aministrà aquel article',
	'titre_image_administrateur' => 'Aministratour',
	'titre_image_aide' => 'D’ajuda sus aquel elemen',
	'titre_image_auteur_supprime' => 'Autour suprimat',
	'titre_image_redacteur' => 'Redatour sensa achès',
	'titre_image_redacteur_02' => 'Redatour',
	'titre_image_selecteur' => 'Afichà la lista',
	'titre_image_visiteur' => 'Visitaire',
	'titre_joindre_document' => 'JOUGNE UN DOUCUMEN',
	'titre_mots_cles' => 'MOT CLAU',
	'titre_probleme_technique' => 'Mèfi : un proublema tecnic (servidou SQL) empacha d’achedre en aquela part dóu sit. Mercì de la vouòstra indulgença.',
	'titre_publier_document' => 'PUBLICÀ UN DOUCUMEN EN AQUELA RÙBRICA',
	'titre_signatures_attente' => 'Firma en aspèra de validacioun',
	'titre_signatures_confirmees' => 'Firma counfirmadi',
	'titre_statistiques' => 'Estatistica dóu sit',
	'titre_titre_document' => 'Titre dóu doucumen :',
	'todo' => 'Da venì',
	'trad_definir_reference' => 'Chausì "@titre@" couma referença dei traducioun',
	'trad_reference' => '(referença dei traducioun)',

	// Z
	'zbug_balise_b_aval' => ' : balisa B davau',
	'zbug_balise_inexistante' => 'Balisa @balise@ mau declarada per @from@ ',
	'zbug_balise_sans_argument' => 'Argumen mancant en la balisa @balise@',
	'zbug_boucle' => 'blouca',
	'zbug_boucle_recursive_undef' => 'blouca recursiva noun definida : @nom@',
	'zbug_calcul' => 'carcul',
	'zbug_champ_hors_boucle' => 'Camp @champ@ fouòra de blouca',
	'zbug_champ_hors_motif' => 'Camp @champ@ fouòra d’un counteste @motif@',
	'zbug_code' => 'code',
	'zbug_critere_inconnu' => 'critèri escounouissut @critere@',
	'zbug_critere_sur_table_sans_cle_primaire' => '{@critere@} sus una taula sensa clau primari atoumica',
	'zbug_distant_interdit' => 'Estèrnou prouhibit', # Contexte : une base de données "externe", pas gérée par SPIP, mais que SPIP 1.8 sait utiliser dans ses boucles -- seul problèmes certaines manipulations sont interdites sur ces bases-là.
	'zbug_doublon_table_sans_cle_primaire' => 'doubloun sus una taula sensa clau primari atoumica',
	'zbug_doublon_table_sans_index' => 'doubloun sus una taula sensa ìndice',
	'zbug_erreur_boucle_double' => 'Double definicioun de la blouca @id@',
	'zbug_erreur_boucle_fermant' => 'Blouca @id@ noun fermada',
	'zbug_erreur_boucle_syntaxe' => 'Sintassa de la blouca mau courreta',
	'zbug_erreur_compilation' => 'Errour de coumpilacioun',
	'zbug_erreur_execution_page' => 'errour d’esecucioun de la pàgina',
	'zbug_erreur_filtre' => 'Errour : filtre <b>« @filtre@ »</b> noun definit',
	'zbug_erreur_meme_parent' => '{meme_parent} s’aplica unicamen ai blouca (FORUMS) o (RUBRIQUES)',
	'zbug_erreur_squelette' => 'Errour en l’esquelètrou',
	'zbug_hors_compilation' => 'Fouòra Coumpilacioun',
	'zbug_info_erreur_squelette' => 'Error soubre lou sit',
	'zbug_inversion_ordre_inexistant' => 'inversioun d’un ordre inesistent',
	'zbug_pagination_sans_critere' => 'Balisa #PAGINATION sensa critèri {pagination} o emplegada en una blouca recoursiva',
	'zbug_parametres_inclus_incorrects' => 'Parametre d’enclusioun mau courret : @param@',
	'zbug_profile' => 'Tems de carcul : @time@',
	'zbug_resultat' => 'resultat',
	'zbug_serveur_indefini' => 'servidou SQL indefinit',
	'zbug_statistiques' => 'Estatìstica dei requesta SQL classificadi per durada',
	'zbug_table_inconnue' => 'Taula SQL « @table@ » escounouissuda',
	'zxml_connus_attributs' => 'atribut counouissut',
	'zxml_de' => 'de',
	'zxml_inconnu_attribut' => 'atribut escounouissut',
	'zxml_inconnu_balise' => 'balisa escounouissuda',
	'zxml_inconnu_entite' => 'entitat escounouissuda',
	'zxml_inconnu_id' => 'ID escounouissut',
	'zxml_mais_de' => 'mà de',
	'zxml_non_conforme' => 'noun es counforme au moutiéu',
	'zxml_non_fils' => 'noun es un enfant de',
	'zxml_nonvide_balise' => 'balisa noun vuèia',
	'zxml_obligatoire_attribut' => 'atribut oubligatori mà assent en',
	'zxml_succession_fils_incorrecte' => 'suchessioun dei enfant mau courret',
	'zxml_survoler' => 'survolà per veire lu courret',
	'zxml_valeur_attribut' => 'valour de l’atribut',
	'zxml_vide_balise' => 'balisa vuèia',
	'zxml_vu' => 'vist adé'
);

?>
